import { Icons, type Icon } from '@/components/ui/Icon';
import { ReactNode } from 'react';

/**
 * A navigation item.
 *
 * @typedef {Object} NavItem
 *
 * @property {string} name - The name of the navigation item.
 * @property {string} slug - The slug of the navigation item.
 * @property {boolean} [disabled] - Whether the navigation item is disabled.
 */
export type NavItem = {
  name: string;
  slug: string;
  icon: string;
  disabled?: boolean;
};

/**
 * Navigation items.
 *
 * @type {NavItem[]}
 */
export const navItems: NavItem[] = [
  {
    name: 'Dashboard',
    slug: 'dashboard',
    icon: 'dashboard-line',
    disabled: false
  },
  {
    name: 'Classement',
    slug: 'dashboard/leaderboard',
    icon: 'line-chart-line',
    disabled: false
  },
  {
    name: 'Puzzles',
    slug: 'dashboard/puzzles',
    icon: 'code-s-slash-line',
    disabled: false
  },
  {
    name: 'Badges',
    slug: 'dashboard/badges',
    icon: 'award-fill',
    disabled: false
  },
  {
    name: 'Paramètres',
    slug: 'dashboard/settings',
    icon: 'equalizer-line',
    disabled: false
  }
];
